@@ -83,12 +83,17 @@ def check_displays():
             outputs = json.loads(json_string)
             for output in outputs:
                 if output['active']:  # dunno WTF xroot-0 is: i3 returns such an output with "active":false
+                    g_name = output["make"] if output["make"] != "Unknown" else ""
+                    if output["model"] and output["model"] != "Unknown":
+                        g_name += " {}".format(output["model"])
+                    if output["serial"] and output["serial"] != "Unknown":
+                        g_name += " {}".format(output["serial"])
                     display = {'name': output['name'],
                                'x': output['rect']['x'],
                                'y': output['rect']['y'],
                                'width': output['rect']['width'],
                                'height': output['rect']['height'],
-                               'generic-name': "{} {} {}".format(output["make"], output["model"], output["serial"])}
+                               'generic-name': g_name}
                     displays.append(display)
                     log("Output found: {}".format(display), common.INFO)
                 try:
@@ -110,9 +115,14 @@ def check_displays():
 
     elif os.getenv("HYPRLAND_INSTANCE_SIGNATURE"):
         print("Running on Hyprland")
+        # /tmp/hypr moved to $XDG_RUNTIME_DIR/hypr in #5788
+        xdg_runtime_dir = os.getenv("XDG_RUNTIME_DIR")
+        hypr_dir = f"{xdg_runtime_dir}/hypr" if xdg_runtime_dir and os.path.isdir(
+            f"{xdg_runtime_dir}/hypr") else "/tmp/hypr"
+
         import socket
         s = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
-        s.connect("/tmp/hypr/{}/.socket.sock".format(os.getenv("HYPRLAND_INSTANCE_SIGNATURE")))
+        s.connect("{}/{}/.socket.sock".format(hypr_dir, os.getenv("HYPRLAND_INSTANCE_SIGNATURE")))
 
         s.send("j/monitors".encode("utf-8"))
         output = s.recv(20480).decode('utf-8')
@@ -120,12 +130,17 @@ def check_displays():
         displays = []
         clients = json.loads(output)
         for c in clients:
+            g_name = c["make"] if c["make"] else ""
+            if c["model"]:
+                g_name += " {}".format(c["model"])
+            if c["serial"]:
+                g_name += " {}".format(c["serial"])
             display = {'name': c['name'],
                        'x': c['x'],
                        'y': c['y'],
                        'width': c['width'],
                        'height': c['height'],
-                       'generic-name': "{} {} {}".format(c["make"], c["model"], c["serial"])}
+                       'generic-name': g_name}
             displays.append(display)
             log("Output found: {}".format(display), common.INFO)
 
@@ -353,8 +368,11 @@ def set_env(__version__, lang_from_args=None):
     if not os.path.isdir(common.thumb_dir):
         os.mkdir(common.thumb_dir)
 
-    # command file
-    common.cmd_file = os.path.join(os.getenv("HOME"), ".azotebg")
+    # command file; let's use separate file name for Hyprland, as generic display names may be different
+    if os.getenv("HYPRLAND_INSTANCE_SIGNATURE"):
+        common.cmd_file = os.path.join(os.getenv("HOME"), ".azotebg-hyprland")
+    else:
+        common.cmd_file = os.path.join(os.getenv("HOME"), ".azotebg")
 
     # temporary folder
     common.tmp_dir = os.path.join(common.data_home, "temp")
@@ -556,32 +574,31 @@ def hash_name(full_path):
 
 
 def create_thumbnails(scr_path):
-    # Let's count allowed files first
     common.progress_bar.hide()
     counter = 0
-    for extension in common.allowed_file_types:
-        for in_path in glob.glob(os.path.join(scr_path, "*.{}".format(extension))):
-            if file_allowed(in_path):
-                counter += 1
+    inames = "-iname \"*."+"\" -o -iname \"*.".join(common.allowed_file_types)+"\""
+    files=subprocess.check_output("find '%s' -mindepth 1 %s" %(scr_path, inames), shell=True).decode().split("\n")[:-1]
+    for in_path in files:
+        if file_allowed(in_path):
+            counter += 1
     if counter > 0:
         # get all the files of allowed types from current path
         common.progress_bar.show()
         common.progress_bar.set_fraction(0.0)
         processed = 0
-        for extension in common.allowed_file_types:
-            for in_path in glob.glob(os.path.join(scr_path, "*.{}".format(extension))):
-                if file_allowed(in_path):
-                    thumb_name = "{}.png".format(hash_name(in_path))
-                    dest_path = os.path.join(common.thumb_dir, thumb_name)
-                    if not os.path.isfile(dest_path):
-                        create_thumbnail(in_path, dest_path, thumb_name)
-                    elif is_newer(in_path, dest_path):
-                        create_thumbnail(in_path, dest_path, thumb_name, True)
-                    processed += 1
-                    common.progress_bar.set_fraction(processed / counter)
-                    common.progress_bar.set_text(str(processed))
-                    while Gtk.events_pending():
-                        Gtk.main_iteration()
+        for in_path in files:
+            if file_allowed(in_path):
+                thumb_name = "{}.png".format(hash_name(in_path))
+                dest_path = os.path.join(common.thumb_dir, thumb_name)
+                if not os.path.isfile(dest_path):
+                    create_thumbnail(in_path, dest_path, thumb_name)
+                elif is_newer(in_path, dest_path):
+                    create_thumbnail(in_path, dest_path, thumb_name, True)
+                processed += 1
+                common.progress_bar.set_fraction(processed / counter)
+                common.progress_bar.set_text(str(processed))
+                while Gtk.events_pending():
+                    Gtk.main_iteration()
     common.progress_bar.hide()
 
 
@@ -590,7 +607,7 @@ def create_thumbnail(in_path, dest_path, thumb_name, refresh=False):
     try:
         img = Image.open(in_path)
         # convert to thumbnail image
-        img.thumbnail(common.settings.thumb_size, Image.ANTIALIAS)
+        img.thumbnail(common.settings.thumb_size, Image.LANCZOS)
 
         img = expand_img(img)
 
@@ -612,7 +629,7 @@ def flip_selected_wallpaper():
             img_path = os.path.join(common.bcg_dir, "flipped-{}".format(common.selected_wallpaper.filename))
             flipped.save(os.path.join(common.tmp_dir, "flipped-{}".format(common.selected_wallpaper.filename)), "PNG")
 
-            flipped.thumbnail(common.settings.thumb_size, Image.ANTIALIAS)
+            flipped.thumbnail(common.settings.thumb_size, Image.LANCZOS)
             flipped = expand_img(flipped)
 
             thumb_path = os.path.join(common.tmp_dir, "thumbnail-{}".format(common.selected_wallpaper.filename))
@@ -644,7 +661,7 @@ def split_selected_wallpaper(num_parts):
             img_path = os.path.join(common.bcg_dir, "part{}-{}".format(i, common.selected_wallpaper.filename))
             part.save(os.path.join(common.tmp_dir, "part{}-{}".format(i, common.selected_wallpaper.filename)), "PNG")
 
-            part.thumbnail(common.settings.thumb_size, Image.ANTIALIAS)
+            part.thumbnail(common.settings.thumb_size, Image.LANCZOS)
 
             thumb_path = os.path.join(common.tmp_dir, "thumb-part{}-{}".format(i, common.selected_wallpaper.filename))
 
@@ -669,7 +686,7 @@ def expand_img(image):
         # return ImageOps.expand(image, border=border)
         # Let's add checkered background instead of the black one
         background = Image.open('images/squares.jpg')
-        background = background.resize(common.settings.thumb_size, Image.ANTIALIAS)
+        background = background.resize(common.settings.thumb_size, Image.LANCZOS)
         background.paste(image, (border_h, border_v))
         return background
     else:
@@ -686,7 +703,7 @@ def scale_and_crop(item, image_path, width, height):
         new_height = int(width * img.size[1] / img.size[0])
         # Choose the filter depending on if we're scaling down or up
         if new_height >= height:
-            img = img.resize((width, new_height), Image.ANTIALIAS)
+            img = img.resize((width, new_height), Image.LANCZOS)
         else:
             img = img.resize((width, new_height), Image.BILINEAR)
 
@@ -696,7 +713,7 @@ def scale_and_crop(item, image_path, width, height):
     elif new_height > img.size[1]:  # we need to scale to display height and crop horizontal margins
         new_width = int(img.size[0] * height / img.size[1])
         if new_width >= width:
-            img = img.resize((new_width, height), Image.ANTIALIAS)
+            img = img.resize((new_width, height), Image.LANCZOS)
         else:
             img = img.resize((new_width, height), Image.BILINEAR)
 
@@ -704,7 +721,7 @@ def scale_and_crop(item, image_path, width, height):
         img = img.crop((margin, 0, width + margin, height))
 
     else:
-        img = img.resize((width, height), Image.ANTIALIAS)
+        img = img.resize((width, height), Image.LANCZOS)
 
     img.save('{}-{}x{}{}'.format(os.path.splitext(image_path)[0], width, height, os.path.splitext(image_path)[1]))
     common.preview.refresh()
